@@ -1,17 +1,33 @@
 # -*- coding: utf-8 -*-
 #
+"""
+   Copyright 2021 Ashley Sommer
+
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+"""
 import time
 from asyncio import iscoroutinefunction
 from datetime import datetime, timedelta, timezone
 from typing import List
 from os import path, mkdir
-from spf import SanicPluginsFramework, SanicPlugin
-from spf.context import SanicContext
-from spf.plugin import PluginAssociated
+from aiofiles.threadpool import _open as async_open
+from sanic_plugin_toolkit import SanicPluginRealm, SanicPlugin
+from sanic_plugin_toolkit.context import SanicContext
+from sanic_plugin_toolkit.plugin import PluginAssociated
 from sanic import __version__ as sanic_version
 from sanic.request import Request
 from sanic.response import HTTPResponse, StreamingHTTPResponse
-from aiofiles.threadpool import _open as async_open
+
 from .util import recursive_update, datetime_to_iso
 from .version import __version__ as sanic_metrics_version
 
@@ -419,3 +435,9 @@ async def metrics_post_resp(request, response, context):
         await sanic_metrics.log_metrics(metrics, context)
     return False
 
+@sanic_metrics.listener("after_server_start")
+def on_start(app, loop):
+    proxies_count = app.config.PROXIES_COUNT
+    if proxies_count is not None and proxies_count < 1:
+        raise RuntimeError("Please set PROXIES_COUNT > 0 or None")
+
